#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_FAST_FREXP_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_FAST_FREXP_HPP_INCLUDED

#include <boost/simd/ieee/include/functions/simd/fast_frexp.hpp>

#endif
